@@ -42,9 +42,9 @@
 */
 
 #ifdef ROOT_EXEC
-#define MSQL_UNIX_ADDR	"/dev/msql"
+#define MSQL_UNIX_ADDR	"/var/run/msqld/control"
 #else
-#define MSQL_UNIX_ADDR	"/tmp/msql.sock"
+#define MSQL_UNIX_ADDR	"/var/run/msqld/control"
 #endif
 
 
