@@ -15,7 +15,7 @@
 
 main()
 {
-#ifdef HAVE_DIRENT
+#ifdef HAVE_DIRENT_H
 	struct	dirent *dirp;
 	DIR	*TestForNeXT;
 #endif
