@@ -14,7 +14,7 @@ echo	'	$(YACC) $(YACC_FLAGS)'" $src"
 echo	"	mv y.tab.c $outfile"
 echo
 echo	"$obj : $outfile"
-echo    '	$(CC) $(CC_FLAGS)'" -c -o $obj $outfile"
+echo    '	$(CC) $(CC_FLAGS)'" -c $outfile"
 echo
 echo	"clean ::"
 echo	"	rm -f $outfile y.tab.*"
