@@ -30,6 +30,7 @@
 #include <common/portability.h>
 #include "msql_priv.h"
 
+char *ident_client ();
 
 #define	ALLOW	1
 #define REJECT	2
@@ -108,7 +109,11 @@ int msqlLoadAcl(verbose)
 	/*
 	** Open the acl file
 	*/
+#ifndef OLIS
+	(void)sprintf(path,"/etc/msql.acl");
+#else
 	(void)sprintf(path,"%s/msql.acl", msqlHomeDir);
+#endif
 	fp = fopen(path,"r");
 	if (!fp)
 	{
@@ -692,6 +697,14 @@ int msqlCheckAccess(db,info)
 	/*
 	** Now perform any options for this connection
 	*/
+	if (host && matchTextList(curAcl->option,"ident"))
+	{
+	    extern char *ident_client();
+	    char *remoteUser;
+	    remoteUser = ident_client(remote, local);
+	    if (!remoteUser || strcmp(remoteUser, user) != 0)
+		return(NO_ACCESS);
+	}
 
 	
 	return(perms);
