@@ -378,13 +378,14 @@ static m_fdata *tableToFieldList(data)
 **	Notes	: If host == NULL, localhost is used via UNIX domain socket
 */
 
-int msqlConnect(host)
-	char	*host;
+int msqlConnect(myhost)
+	char	*myhost;
 {
 	char	*cp,
 		*envVar,
 		*unixPort;
 	struct	sockaddr_in IPaddr;
+	char	*host = NULL;
 
 #ifdef HAVE_SYS_UN_H
 	struct	sockaddr_un UNIXaddr;
@@ -398,7 +399,6 @@ int msqlConnect(host)
 		tcpPort;
 	struct	passwd *pw;
 
-
 	resetError();
 	initNet();
 	if (!debugInit)
@@ -407,6 +407,12 @@ int msqlConnect(host)
 		msqlInitDebug();
 	}
 
+	if (myhost) {
+		host = (char *)malloc(strlen(myhost)+1);
+		if (!host)
+			return -1;
+		strcpy(host,myhost);
+	}
 	/*
 	** Grab a socket and connect it to the server
 	*/
@@ -464,6 +470,12 @@ int msqlConnect(host)
         	{
                 	tcpPort = atoi(envVar);
         	}
+		if ((cp=index (host, ':')))
+		{
+			*cp='\0';
+			cp++;
+			tcpPort = atoi(cp);
+		}
 
 		sprintf(hostInfo,"%s via TCP/IP",host);
 		msqlDebug(MOD_API,"Server name = %s.  Using TCP sock (%d)\n",
