@@ -16,6 +16,8 @@
 **
 */
 
+#ifndef __MSQL_H__
+#define __MSQL_H__
 
 #if defined(__STDC__) || defined(__cplusplus)
 #  define __ANSI_PROTO(x)	x
@@ -109,3 +111,5 @@ typedef struct result_s {
 #ifdef __cplusplus
 	}
 #endif
+
+#endif /* __MSQL_H__ */
