@@ -64,7 +64,10 @@ typedef struct val_s {
 		double	realVal;
 		ident_t	*identVal;
 	} val;
-	int	type,
+	char	table[NAME_LEN],
+		name[NAME_LEN];
+	int	op,offs,ftype,
+		type,
 		nullVal,
 		dataLen;
 } val_t;
@@ -246,6 +249,12 @@ typedef char	* C_PTR;
 #define GE_OP		6
 #define LIKE_OP		7
 #define NOT_LIKE_OP	8
+#define ILIKE_OP	9
+#define NOT_ILIKE_OP	10
+#define PLUS_OP		11
+#define MINUS_OP	12
+#define MULT_OP		13
+#define DIV_OP		14
 
 #define	NO_BOOL		0
 #define	AND_BOOL	1
