@@ -246,6 +246,8 @@ val_t *msqlCreateValue(textRep,type,tokLen)
 
 	msqlTrace(TRACE_IN,"msqlCreateValue()");
 	new = (val_t *)malloc(sizeof(val_t));
+	*(new->table) = *(new->name) = 0;
+	new->offs=0;
 	new->type = type;
 	new->dataLen = tokLen;
 	switch(type)
@@ -507,12 +509,13 @@ msqlSetSelectLimit(value)
 }
 
 
-msqlAddFieldValue(value)
+msqlAddFieldValue(value,ident,operator)
 	val_t	*value;
+	ident_t *ident;
+	int operator;
 {
 	register field_t	*fieldVal;
 	u_char	*buf;
-
 	msqlTrace(TRACE_IN,"msqlAddFieldValue()");
 	if (!lastField)
 	{
@@ -523,6 +526,22 @@ msqlAddFieldValue(value)
 		fieldVal = lastField->next;
 		lastField = lastField->next;
 	}
+	if (ident && operator)
+	{
+		value->op=operator;
+
+		if (*(ident->seg1))
+		{
+			(void)strncpy(value->table,ident->seg1,NAME_LEN - 1);
+			(void)strncpy(value->name ,ident->seg2,NAME_LEN - 1);
+		}
+		else
+		{
+			(void)memset(value->table,0,NAME_LEN);
+			(void)strncpy(value->name ,ident->seg2,NAME_LEN - 1);
+		}
+		free(ident);
+	}
 	if (fieldVal)
 	{
 		if (fieldVal->type == CHAR_TYPE)
@@ -564,14 +583,14 @@ int msqlAddCond(ident,op,value,bool)
 
 	msqlTrace(TRACE_IN,"msqlAddCond()");
 
-	if (*(ident->seg2))
+	if (*(ident->seg1))
 	{
 		name = ident->seg2;
 		table = ident->seg1;
 	}
 	else
 	{
-		name = ident->seg1;
+		name = ident->seg2;
 		table = NULL;
 	}
 
