@@ -21,7 +21,7 @@
 #include <sys/types.h>
 #include <fcntl.h>
 
-#ifdef HAVE_DIRENT
+#ifdef HAVE_DIRENT_H
 #  include <dirent.h>
 #else
 #  include <sys/dir.h>
