@@ -55,6 +55,7 @@
 #include "errmsg.h"
 
 
+char *timestamp();
 
 
 extern  char    *yytext;
@@ -164,7 +165,7 @@ initServer()
 	tcpPort = MSQL_PORT;
 	if ((serv_ptr = getservbyname("msql", "tcp")))
 	{
-		tcpPort = ntohs(serv_ptr->s_port);
+		tcpPort = serv_ptr->s_port;
 	}
 	if ((envVar = getenv("MSQL_TCP_PORT")))
 	{
@@ -485,6 +486,13 @@ main(argc,argv)
 			** store the connection details
 			*/
 
+			if (debugSet(MOD_GENERAL))
+				fprintf(stderr,"\n");
+			if (debugSet(MOD_GENERAL) && !debugSet(MOD_QUERY))
+			{
+				fprintf(stderr, "\n");
+				msqlDebug(MOD_GENERAL,"\n%s\n", timestamp());
+			}
 			msqlDebug(MOD_GENERAL,"New connection received on %d\n",
 				newSock);
 			error = 0;
@@ -634,7 +642,10 @@ main(argc,argv)
 				cp=(char *)(packet+2);
 				arg = (char *)strdup(cp);
 				if (debugSet(MOD_QUERY))
-					fprintf(stderr,"\n");
+				{
+					fprintf(stderr, "\n");
+					msqlDebug(MOD_QUERY,"%s\n", timestamp());
+				}
 				msqlDebug(MOD_QUERY,"Query = %s",arg);
 				msqlSetDB(conArray[comSock].db);
 				msqlSetPerms(conArray[comSock].access);
